#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""this file contains the version of translate"""
ver = "0.10.1"
build = "9900"
